@@ -18,7 +18,6 @@
 #include "solver.h"
 #include "verify.h"
 #include "tic.h"
-#include "solvedclient.h"
 #include "solvedfile.h"
 #include "fit-wcs.h"
 #include "sip-utils.h"
@@ -1429,10 +1428,10 @@ static int solver_handle_hit(solver_t* sp, MatchObj* mo, sip_t* verifysip,
 
     // Also copy original field star coordinates
     //mo.quadpix_orig
-    printf("mo field stars:\n");
+    logverb("mo field stars:\n");
     int i;
     for (i=0; i<mo->dimquads; i++) {
-        printf("  star %i; field_xy %.1f,%.1f, field_orig %.1f,%.1f\n",
+        logverb("  star %i; field_xy %.1f,%.1f, field_orig %.1f,%.1f\n",
                mo->field[i], mo->quadpix[2*i+0], mo->quadpix[2*i+1],
                starxy_getx(sp->fieldxy_orig, mo->field[i]),
                starxy_gety(sp->fieldxy_orig, mo->field[i]));
@@ -1521,6 +1520,7 @@ static int solver_handle_hit(solver_t* sp, MatchObj* mo, sip_t* verifysip,
                                            sp->crpix[0], sp->crpix[1], &dx, &dy);
                 } else {
                     dx = sp->crpix[0] / sp->pixel_xscale;
+                    dy = sp->crpix[1];
                 }
                 tan_pixelxy2radecarr(&mo->wcstan, dx, dy, sip->wcstan.crval);
 
